@@ -586,7 +586,10 @@ WipeTower::WipeTower(const Vec2f& pos, double rotation_deg, const PrintConfig& c
         m_set_extruder_trimpot    = config.high_current_on_filament_swap;
     }
 
-    m_is_mk4mmu3                 = boost::icontains(config.printer_notes.value, "PRINTER_MODEL_MK4") && boost::icontains(config.printer_notes.value, "MMU");
+    m_is_mk4mmu3 = boost::icontains(config.printer_notes.value, "RAMMING_EXTRA")
+                // Before 2.9.1, the condition was tied to different keywords. We need to keep that so we don't break existing projects:
+                || (boost::icontains(config.printer_notes.value, "PRINTER_MODEL_MK4") && boost::icontains(config.printer_notes.value, "MMU"));
+
     m_switch_filament_monitoring = m_is_mk4mmu3 || is_XL_printer(config);
 
     // Calculate where the priming lines should be - very naive test not detecting parallelograms etc.
@@ -936,10 +939,10 @@ void WipeTower::toolchange_Unload(
         }
     }
 
-    if (m_switch_filament_monitoring) {
+    if (m_switch_filament_monitoring)
         writer.switch_filament_monitoring(false);
+    if (m_is_mk4mmu3)
         writer.wait(1.5f);
-    }
     
 
     // now the ramming itself:
@@ -1161,6 +1164,15 @@ void WipeTower::toolchange_Wipe(
 	float dy = (is_first_layer() ? m_extra_flow : m_extra_spacing_wipe) * m_perimeter_width; // Don't use the extra spacing for the first layer, but do use the spacing resulting from increased flow.
     // All the calculations in all other places take the spacing into account for all the layers.
 
+    // Ensure that for the first layer, the cleaning_box will be entirely filled.
+    if (is_first_layer()) {
+        const float cleaning_box_height    = cleaning_box.lu.y() - (0.5f * line_width) - float(EPSILON) - (writer.y() + dy);
+        const int   extrusion_cnt          = static_cast<int>(std::floor(cleaning_box_height / dy)) + 1;
+        const float extrusion_length       = xr - xl;
+        const float x_to_fill_cleaning_box = extrusion_length * static_cast<float>(extrusion_cnt);
+        x_to_wipe = std::max(x_to_wipe, x_to_fill_cleaning_box);
+    }
+
     const float target_speed = is_first_layer() ? m_first_layer_speed * 60.f : m_infill_speed * 60.f;
     float wipe_speed = 0.33f * target_speed;
 
