@@ -5,7 +5,14 @@
 #ifndef slic3r_IntersectionPoints_hpp_
 #define slic3r_IntersectionPoints_hpp_
 
+#include <stdint.h>
+#include <vector>
+#include <cinttypes>
+
 #include "ExPolygon.hpp"
+#include "libslic3r/Line.hpp"
+#include "libslic3r/Point.hpp"
+#include "libslic3r/Polygon.hpp"
 
 namespace Slic3r {
 
