@@ -6,10 +6,15 @@
 #include "MeshBoolean.hpp"
 #include "libslic3r/TriangleMesh.hpp"
 #include "libslic3r/TryCatchSignal.hpp"
+#include "libslic3r/Point.hpp"
+
 #undef PI
 
 // Include igl first. It defines "L" macro which then clashes with our localization
-#include <igl/copyleft/cgal/mesh_boolean.h>
+#include <igl/copyleft/cgal/mesh_boolean.h> // IWYU pragma: keep
+#include <igl/MeshBooleanType.h>
+#include <boost/property_map/property_map.hpp>
+
 #undef L
 
 // CGAL headers
@@ -17,6 +22,10 @@
 #include <CGAL/Exact_integer.h>
 #include <CGAL/Surface_mesh.h>
 #include <CGAL/Cartesian_converter.h>
+#include <algorithm>
+#include <set>
+#include <csignal>
+#include <map>
 
 namespace Slic3r {
 namespace MeshBoolean {
