@@ -1,8 +1,19 @@
+///|/ Copyright (c) Prusa Research 2017 - 2022 Tomáš Mészáros @tamasmeszaros, Vojtěch Bubník @bubnikv, Filip Sykala @Jony01
+///|/
+///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
+///|/
 #ifndef slic3r_MutablePriorityQueue_hpp_
 #define slic3r_MutablePriorityQueue_hpp_
 
 #include <assert.h>
 #include <type_traits>
+#include <vector>
+#include <limits>
+#include <cstdlib> // adds size_t (without std::)
+
+namespace Slic3r {
+
+constexpr auto InvalidQueueID = std::numeric_limits<size_t>::max();
 
 template<typename T, typename IndexSetter, typename LessPredicate, const bool ResetIndexWhenRemoved = false>
 class MutablePriorityQueue
@@ -17,6 +28,14 @@ public:
 		{}
 	~MutablePriorityQueue()	{ clear(); }
 
+	MutablePriorityQueue(MutablePriorityQueue &&) = default;
+	MutablePriorityQueue& operator=(MutablePriorityQueue &&) = default;
+
+	// This class modifies the outside data through the m_index_setter
+	// and thus it should not be copied. The semantics is similar to std::unique_ptr
+	MutablePriorityQueue(const MutablePriorityQueue &) = delete;
+	MutablePriorityQueue& operator=(const MutablePriorityQueue &) = delete;
+
 	void		clear();
 	void		reserve(size_t cnt) 				{ m_heap.reserve(cnt); }
 	void		push(const T &item);
@@ -30,6 +49,7 @@ public:
 	bool		empty() const						{ return m_heap.empty(); }
 	T&			operator[](std::size_t idx) noexcept { return m_heap[idx]; }
 	const T&	operator[](std::size_t idx) const noexcept { return m_heap[idx]; }
+    static constexpr size_t invalid_id() { return InvalidQueueID; }
 
 	using iterator		 = typename std::vector<T>::iterator;
 	using const_iterator = typename std::vector<T>::const_iterator;
@@ -58,14 +78,10 @@ MutablePriorityQueue<T, IndexSetter, LessPredicate, ResetIndexWhenRemoved> make_
 template<class T, class LessPredicate, class IndexSetter, const bool ResetIndexWhenRemoved>
 inline void MutablePriorityQueue<T, LessPredicate, IndexSetter, ResetIndexWhenRemoved>::clear()
 { 
-#ifdef NDEBUG
-	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		for (size_t idx = 0; idx < m_heap.size(); ++ idx)
 			// Mark as removed from the queue.
-			m_index_setter(m_heap[idx], std::numeric_limits<size_t>::max());
+			m_index_setter(m_heap[idx], this->invalid_id());
 	}
 	m_heap.clear();
 }
@@ -92,13 +108,9 @@ template<class T, class LessPredicate, class IndexSetter, const bool ResetIndexW
 inline void MutablePriorityQueue<T, LessPredicate, IndexSetter, ResetIndexWhenRemoved>::pop()
 {
 	assert(! m_heap.empty());
-#ifdef NDEBUG
-	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		// Mark as removed from the queue.
-		m_index_setter(m_heap.front(), std::numeric_limits<size_t>::max());
+		m_index_setter(m_heap.front(), this->invalid_id());
 	}
 	if (m_heap.size() > 1) {
 		m_heap.front() = m_heap.back();
@@ -113,13 +125,10 @@ template<class T, class LessPredicate, class IndexSetter, const bool ResetIndexW
 inline void MutablePriorityQueue<T, LessPredicate, IndexSetter, ResetIndexWhenRemoved>::remove(size_t idx)
 {
 	assert(idx < m_heap.size());
-#ifdef NDEBUG
 	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		// Mark as removed from the queue.
-		m_index_setter(m_heap[idx], std::numeric_limits<size_t>::max());
+		m_index_setter(m_heap[idx], this->invalid_id());
 	}
 	if (idx + 1 == m_heap.size()) {
 		m_heap.pop_back();
@@ -266,6 +275,14 @@ public:
 		{}
 	~MutableSkipHeapPriorityQueue()	{ clear(); }
 
+	MutableSkipHeapPriorityQueue(MutableSkipHeapPriorityQueue &&) = default;
+    MutableSkipHeapPriorityQueue &operator=(MutableSkipHeapPriorityQueue &&) = default;
+
+    // This class modifies the outside data through the m_index_setter
+    // and thus it should not be copied. The semantics is similar to std::unique_ptr
+    MutableSkipHeapPriorityQueue(const MutableSkipHeapPriorityQueue &) = delete;
+    MutableSkipHeapPriorityQueue &operator=(const MutableSkipHeapPriorityQueue &) = delete;
+
 	void		clear();
 	// Reserve one unused element per miniheap.
 	void		reserve(size_t cnt) 				{ m_heap.reserve(cnt + ((cnt + (address::block_size - 1)) / (address::block_size - 1))); }
@@ -277,9 +294,12 @@ public:
 	void		update(size_t idx) 					{ assert(! address::is_padding(idx)); T item = m_heap[idx]; remove(idx); push(item); }
 	// There is one padding element storead at each miniheap, thus lower the number of elements by the number of miniheaps.
 	size_t 		size() const noexcept 				{ return m_heap.size() - (m_heap.size() + address::block_size - 1) / address::block_size; }
+	// Number of heap elements including padding. heap_size() >= size().
+	size_t      heap_size() const noexcept          { return m_heap.size(); }
 	bool		empty() const						{ return m_heap.empty(); }
 	T&			operator[](std::size_t idx) noexcept { assert(! address::is_padding(idx)); return m_heap[idx]; }
 	const T&    operator[](std::size_t idx) const noexcept { assert(! address::is_padding(idx)); return m_heap[idx]; }
+    static constexpr size_t invalid_id() { return InvalidQueueID; }
 
 protected:
 	void		update_heap_up(size_t top, size_t bottom);
@@ -309,15 +329,11 @@ MutableSkipHeapPriorityQueue<T, IndexSetter, LessPredicate, BlockSize, ResetInde
 template<class T, class LessPredicate, class IndexSetter, std::size_t blocking, const bool ResetIndexWhenRemoved>
 inline void MutableSkipHeapPriorityQueue<T, LessPredicate, IndexSetter, blocking, ResetIndexWhenRemoved>::clear()
 { 
-#ifdef NDEBUG
-	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		for (size_t idx = 0; idx < m_heap.size(); ++ idx)
 			// Mark as removed from the queue.
 			if (! address::is_padding(idx))
-				m_index_setter(m_heap[idx], std::numeric_limits<size_t>::max());
+				m_index_setter(m_heap[idx], this->invalid_id());
 	}
 	m_heap.clear();
 }
@@ -348,13 +364,9 @@ template<class T, class LessPredicate, class IndexSetter, std::size_t blocking,
 inline void MutableSkipHeapPriorityQueue<T, LessPredicate, IndexSetter, blocking, ResetIndexWhenRemoved>::pop()
 {
 	assert(! m_heap.empty());
-#ifdef NDEBUG
-	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		// Mark as removed from the queue.
-		m_index_setter(m_heap[1], std::numeric_limits<size_t>::max());
+        m_index_setter(m_heap[1], this->invalid_id());
 	}
 	// Zero'th element is padding, thus non-empty queue must have at least two elements.
 	if (m_heap.size() > 2) {
@@ -371,13 +383,9 @@ inline void MutableSkipHeapPriorityQueue<T, LessPredicate, IndexSetter, blocking
 {
 	assert(idx < m_heap.size());
 	assert(! address::is_padding(idx));
-#ifdef NDEBUG
-	// Only mark as removed from the queue in release mode, if configured so.
-	if (ResetIndexWhenRemoved)
-#endif /* NDEBUG */
-	{
+	if constexpr (ResetIndexWhenRemoved) {
 		// Mark as removed from the queue.
-		m_index_setter(m_heap[idx], std::numeric_limits<size_t>::max());
+        m_index_setter(m_heap[idx], this->invalid_id());
 	}
 	if (idx + 1 == m_heap.size()) {
 		this->pop_back();
@@ -450,4 +458,6 @@ inline void MutableSkipHeapPriorityQueue<T, LessPredicate, IndexSetter, blocking
 	}
 }
 
+} // namespace Slic3r
+
 #endif /* slic3r_MutablePriorityQueue_hpp_ */
