@@ -1,15 +1,25 @@
+///|/ Copyright (c) Prusa Research 2020 - 2022 Tomáš Mészáros @tamasmeszaros, Vojtěch Bubník @bubnikv
+///|/ Copyright (c) 2022 ole00 @ole00
+///|/
+///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
+///|/
 #ifndef SLA_RASTERBASE_HPP
 #define SLA_RASTERBASE_HPP
 
+#include <libslic3r/ExPolygon.hpp>
+#include <stddef.h>
 #include <ostream>
 #include <memory>
 #include <vector>
 #include <array>
 #include <utility>
 #include <cstdint>
+#include <functional>
+#include <string>
+#include <cstddef>
 
-#include <libslic3r/ExPolygon.hpp>
-#include <libslic3r/SLA/Concurrency.hpp>
+#include "libslic3r/Point.hpp"
+#include "libslic3r/libslic3r.h"
 
 namespace Slic3r {
 
@@ -31,6 +41,27 @@ public:
     const char * extension() const { return m_ext.c_str(); }
 };
 
+/// Type that represents a resolution in pixels.
+struct Resolution {
+    size_t width_px = 0;
+    size_t height_px = 0;
+
+    Resolution() = default;
+    Resolution(size_t w, size_t h) : width_px(w), height_px(h) {}
+    size_t pixels() const { return width_px * height_px; }
+};
+
+/// Types that represents the dimension of a pixel in millimeters.
+struct PixelDim {
+    double w_mm = 1.;
+    double h_mm = 1.;
+
+    PixelDim() = default;
+    PixelDim(double px_width_mm, double px_height_mm)
+        : w_mm(px_width_mm), h_mm(px_height_mm)
+    {}
+};
+
 using RasterEncoder =
     std::function<EncodedRaster(const void *ptr, size_t w, size_t h, size_t num_components)>;
 
@@ -40,10 +71,10 @@ public:
     enum Orientation { roLandscape, roPortrait };
     
     using TMirroring = std::array<bool, 2>;
-    static const TMirroring NoMirror;
-    static const TMirroring MirrorX;
-    static const TMirroring MirrorY;
-    static const TMirroring MirrorXY;
+    static const constexpr TMirroring NoMirror = {false, false};
+    static const constexpr TMirroring MirrorX  = {true, false};
+    static const constexpr TMirroring MirrorY  = {false, true};
+    static const constexpr TMirroring MirrorXY = {true, true};
     
     struct Trafo {
         bool mirror_x = false, mirror_y = false, flipXY = false;
@@ -63,35 +94,14 @@ public:
         Point get_center() const { return {center_x, center_y}; }
     };
     
-    /// Type that represents a resolution in pixels.
-    struct Resolution {
-        size_t width_px = 0;
-        size_t height_px = 0;
-        
-        Resolution() = default;
-        Resolution(size_t w, size_t h) : width_px(w), height_px(h) {}
-        size_t pixels() const { return width_px * height_px; }
-    };
-    
-    /// Types that represents the dimension of a pixel in millimeters.
-    struct PixelDim {
-        double w_mm = 1.;
-        double h_mm = 1.;
-        
-        PixelDim() = default;
-        PixelDim(double px_width_mm, double px_height_mm)
-            : w_mm(px_width_mm), h_mm(px_height_mm)
-        {}
-    };
-    
     virtual ~RasterBase() = default;
     
     /// Draw a polygon with holes.
     virtual void draw(const ExPolygon& poly) = 0;
     
     /// Get the resolution of the raster.
-    virtual Resolution resolution() const = 0;
-    virtual PixelDim   pixel_dimensions() const = 0;
+//    virtual Resolution resolution() const = 0;
+//    virtual PixelDim   pixel_dimensions() const = 0;
     virtual Trafo      trafo() const = 0;
     
     virtual EncodedRaster encode(RasterEncoder encoder) const = 0;
@@ -109,10 +119,10 @@ std::ostream& operator<<(std::ostream &stream, const EncodedRaster &bytes);
 
 // If gamma is zero, thresholding will be performed which disables AA.
 std::unique_ptr<RasterBase> create_raster_grayscale_aa(
-    const RasterBase::Resolution &res,
-    const RasterBase::PixelDim &  pxdim,
-    double                        gamma = 1.0,
-    const RasterBase::Trafo &     tr    = {});
+    const Resolution        &res,
+    const PixelDim          &pxdim,
+    double                   gamma = 1.0,
+    const RasterBase::Trafo &tr    = {});
 
 }} // namespace Slic3r::sla
 
