@@ -1,10 +1,14 @@
+///|/ Copyright (c) Prusa Research 2020 - 2022 Tomáš Mészáros @tamasmeszaros, Lukáš Matěna @lukasmatena, Vojtěch Bubník @bubnikv
+///|/
+///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
+///|/
 #ifndef REPROJECTPOINTSONMESH_HPP
 #define REPROJECTPOINTSONMESH_HPP
 
 #include "libslic3r/Point.hpp"
+#include "libslic3r/AABBMesh.hpp"
 #include "SupportPoint.hpp"
 #include "Hollowing.hpp"
-#include "IndexedMesh.hpp"
 #include "libslic3r/Model.hpp"
 
 #include <tbb/parallel_for.h>
@@ -15,7 +19,7 @@ template<class Pt> Vec3d pos(const Pt &p) { return p.pos.template cast<double>()
 template<class Pt> void pos(Pt &p, const Vec3d &pp) { p.pos = pp.cast<float>(); }
 
 template<class PointType>
-void reproject_support_points(const IndexedMesh &mesh, std::vector<PointType> &pts)
+void reproject_support_points(const AABBMesh &mesh, std::vector<PointType> &pts)
 {
     tbb::parallel_for(size_t(0), pts.size(), [&mesh, &pts](size_t idx) {
         int junk;
@@ -33,7 +37,7 @@ inline void reproject_points_and_holes(ModelObject *object)
     if (!object || (!has_holes && !has_sppoints)) return;
 
     TriangleMesh rmsh = object->raw_mesh();
-    IndexedMesh emesh{rmsh};
+    AABBMesh emesh{rmsh};
 
     if (has_sppoints)
         reproject_support_points(emesh, object->sla_support_points);
