@@ -5,8 +5,13 @@
 #ifndef SRC_LIBSLIC3R_SHORTEDGECOLLAPSE_HPP_
 #define SRC_LIBSLIC3R_SHORTEDGECOLLAPSE_HPP_
 
+#include <stddef.h>
+#include <cstddef>
+
 #include "libslic3r/TriangleMesh.hpp"
 
+struct indexed_triangle_set;
+
 namespace Slic3r{
 
 // Decimates the model by collapsing short edges. It starts with very small edges and gradually increases the collapsible length,
