@@ -13,16 +13,26 @@
 #ifndef slic3r_TreeModelVolumes_hpp
 #define slic3r_TreeModelVolumes_hpp
 
+#include <boost/functional/hash.hpp>
+#include <assert.h>
+#include <stddef.h>
+#include <stdint.h>
 #include <mutex>
 #include <unordered_map>
-
-#include <boost/functional/hash.hpp>
+#include <functional>
+#include <map>
+#include <optional>
+#include <utility>
+#include <vector>
+#include <cassert>
+#include <cinttypes>
+#include <cstddef>
 
 #include "TreeSupportCommon.hpp"
-
 #include "../Point.hpp"
 #include "../Polygon.hpp"
 #include "../PrintConfig.hpp"
+#include "libslic3r/libslic3r.h"
 
 namespace Slic3r
 {
@@ -244,12 +254,16 @@ private:
          */
         std::optional<std::reference_wrapper<const Polygons>> getArea(const TreeModelVolumes::RadiusLayerPair &key) const {
             std::lock_guard<std::mutex> guard(m_mutex);
+
             if (key.second >= LayerIndex(m_data.size()))
-                return std::optional<std::reference_wrapper<const Polygons>>{};
-            const auto &layer = m_data[key.second];
+                return std::nullopt;
+
+            const LayerData &layer = m_data[key.second];
             auto it = layer.find(key.first);
-            return it == layer.end() ? 
-                std::optional<std::reference_wrapper<const Polygons>>{} : std::optional<std::reference_wrapper<const Polygons>>{ it->second };
+            if (it == layer.end())
+                return std::nullopt;
+
+            return std::optional<std::reference_wrapper<const Polygons>>{it->second};
         }
         // Get a collision area at a given layer for a radius that is a lower or equial to the key radius.
         std::optional<std::pair<coord_t, std::reference_wrapper<const Polygons>>> get_lower_bound_area(const TreeModelVolumes::RadiusLayerPair &key) const {
