@@ -27,13 +27,15 @@ ConfigWizardWebViewPage::ConfigWizardWebViewPage(ConfigWizard *parent)
 
     // Create the webview
     m_browser_sizer = new wxBoxSizer(wxHORIZONTAL);
-    m_browser = WebView::CreateWebView(this, p_user_account->generate_login_redirect_url(), {});
+    m_browser = WebView::webview_new();
     if (!m_browser) {
         // TRN Config wizard page with a log in page.
         wxStaticText* fail_text = new wxStaticText(this, wxID_ANY, _L("Failed to load a web browser. Logging in is not possible in the moment."));
         append(fail_text);
         return;
     }
+    WebView::webview_create(m_browser, this, p_user_account->generate_login_redirect_url(), {"ExternalApp"});
+    
     if (logged) {
         // TRN Config wizard page with a log in web.
         m_text = new wxStaticText(this, wxID_ANY, format_wxstr(_L("You are logged as %1%."), p_user_account->get_username()));       
@@ -47,11 +49,13 @@ ConfigWizardWebViewPage::ConfigWizardWebViewPage(ConfigWizard *parent)
     append(m_browser_sizer, 1, wxEXPAND);
 
     m_browser_sizer->Show(!logged);
+    Layout();
 
     // Connect the webview events
     Bind(wxEVT_WEBVIEW_ERROR, &ConfigWizardWebViewPage::on_error, this, m_browser->GetId());
     Bind(wxEVT_WEBVIEW_NAVIGATING, &ConfigWizardWebViewPage::on_navigation_request, this, m_browser->GetId());
     Bind(wxEVT_IDLE, &ConfigWizardWebViewPage::on_idle, this);
+    Bind(wxEVT_WEBVIEW_SCRIPT_MESSAGE_RECEIVED, &ConfigWizardWebViewPage::on_script_message, this, m_browser->GetId());
 }
 
 bool ConfigWizardWebViewPage::login_changed()
@@ -102,18 +106,29 @@ void ConfigWizardWebViewPage::load_error_page() {
     m_load_error_page = true;
 }
 
+constexpr bool is_linux =
+#if defined(__linux__)
+true;
+#else
+false;
+#endif
+
 void ConfigWizardWebViewPage::on_idle(wxIdleEvent &WXUNUSED(evt)) {
     if (!m_browser)
         return;
     if (m_browser->IsBusy()) {
-        wxSetCursor(wxCURSOR_ARROWWAIT);
+        if constexpr (!is_linux) { 
+            wxSetCursor(wxCURSOR_ARROWWAIT);
+        }
     } else {
-        wxSetCursor(wxNullCursor);
+        if constexpr (!is_linux) { 
+            wxSetCursor(wxNullCursor);
+        }
 
         if (!m_vetoed && m_load_error_page) {
             m_load_error_page = false;
             m_browser->LoadURL(GUI::format_wxstr(
-                "file://%1%/web/connection_failed.html",
+                "file://%1%/web/other_error.html",
                 boost::filesystem::path(resources_dir()).generic_string()
             ));
         }
@@ -125,16 +140,16 @@ void ConfigWizardWebViewPage::on_navigation_request(wxWebViewEvent &evt)
 {
     wxString url = evt.GetURL();
     if (url.starts_with(L"prusaslicer")) {
-        delete_cookies(m_browser, "https://account.prusa3d.com");
+        delete_cookies(m_browser, Utils::ServiceConfig::instance().account_url());
         delete_cookies(m_browser, "https://accounts.google.com");
         delete_cookies(m_browser, "https://appleid.apple.com");
         delete_cookies(m_browser, "https://facebook.com");
         evt.Veto();
         m_vetoed = true;
         wxPostEvent(wxGetApp().plater(), Event<std::string>(EVT_LOGIN_VIA_WIZARD, into_u8(url)));	
-    } else if (url.Find("accounts.google.com") != wxString::npos 
-        || url.Find("appleid.apple.com") != wxString::npos 
-        || url.Find("facebook.com") != wxString::npos) 
+    } else if (url.Find("accounts.google.com") != wxNOT_FOUND 
+        || url.Find("appleid.apple.com") != wxNOT_FOUND 
+        || url.Find("facebook.com") != wxNOT_FOUND) 
     {
         auto& sc = Utils::ServiceConfig::instance();
         if (!m_evt_sent && !url.starts_with(GUI::from_u8(sc.account_url()))) {
@@ -145,4 +160,11 @@ void ConfigWizardWebViewPage::on_navigation_request(wxWebViewEvent &evt)
         }
     }
 }
+
+void ConfigWizardWebViewPage::on_script_message(wxWebViewEvent& evt)
+{
+    // only reaload button on erro page
+    m_browser->LoadURL(p_user_account->generate_login_redirect_url());
+}
+
 }} // namespace Slic3r::GUI
\ No newline at end of file
