@@ -8,9 +8,14 @@
 #ifndef slic3r_GLShader_hpp_
 #define slic3r_GLShader_hpp_
 
+#include <stddef.h>
 #include <array>
 #include <string>
 #include <string_view>
+#include <initializer_list>
+#include <utility>
+#include <vector>
+#include <cstddef>
 
 #include "libslic3r/Point.hpp"
 
