@@ -122,13 +122,14 @@ public:
 	OG_CustomCtrl*  custom_ctrl{ nullptr };
 	int				ctrl_horiz_alignment{ wxALIGN_LEFT};
     column_t		extra_column {nullptr};
-    t_change		m_on_change { nullptr };
+    t_change		on_change { nullptr };
 	// To be called when the field loses focus, to assign a new initial value to the field.
 	// Used by the relative position / rotation / scale manipulation fields of the Object Manipulation UI.
-    t_kill_focus    m_fill_empty_value { nullptr };
-	std::function<DynamicPrintConfig()>	m_get_initial_config{ nullptr };
-	std::function<DynamicPrintConfig()>	m_get_sys_config{ nullptr };
-	std::function<bool()>	have_sys_config{ nullptr };
+    t_kill_focus    fill_empty_value { nullptr };
+
+	std::function<DynamicPrintConfig()> get_initial_config{ nullptr };
+	std::function<DynamicPrintConfig()> get_sys_config    { nullptr };
+	std::function<bool()>	            have_sys_config   { nullptr };
 
     std::function<void(wxWindow* win)> rescale_extra_column_item { nullptr };
     std::function<void(wxWindow* win)> rescale_near_label_widget { nullptr };
@@ -259,6 +260,9 @@ public:
 	static wxString		get_url(const std::string& path_end);
 	static bool			launch_browser(const std::string& path_end);
 	static bool			is_option_without_field(const std::string& opt_key);
+
+	// Change option value in config
+	static void change_opt_value(DynamicPrintConfig& config, const t_config_option_key& opt_key, const boost::any& value, int opt_index = 0);
 };
 
 class ConfigOptionsGroup: public OptionsGroup {
