@@ -17,6 +17,7 @@
 #include <wx/button.h>
 #include <wx/statbox.h>
 #include <wx/wupdlock.h>
+#include <wx/tooltip.h>
 #if wxUSE_SECRETSTORE 
 #include <wx/secretstore.h>
 #endif
@@ -607,7 +608,8 @@ void PhysicalPrinterDialog::build_printhost_settings(ConfigOptionsGroup* m_optgr
     // Always fill in the "printhost_port" combo box from the config and select it.
     {
         Choice* choice = dynamic_cast<Choice*>(m_optgroup->get_field("printhost_port"));
-        choice->set_values({ m_config->opt_string("printhost_port") });
+        const std::vector<std::string> ports = { m_config->opt_string("printhost_port") };
+        choice->set_values(ports);
         choice->set_selection();
     }
 
