@@ -11,6 +11,7 @@
 namespace Slic3r {
 class ModelVolume;
 typedef std::vector<ModelVolume *> ModelVolumePtrs;
+struct FontProp;
 }
 
 namespace Slic3r::GUI {
@@ -32,18 +33,30 @@ public:
     void reset() { m_model.reset(); m_lines.clear(); }
     const Slic3r::Emboss::TextLines &get_lines() const { return m_lines; }
 
-    static double calc_line_height_in_mm(const Slic3r::Emboss::FontFile& ff, const FontProp& fp); // return lineheight in mm
 private:
     Slic3r::Emboss::TextLines m_lines;
 
     // Keep model for visualization text lines
     GLModel m_model;
-
-    // Used to move slice (text line) on place where is approx vertical center of text
-    // When copy value const double ASCENT_CENTER from Emboss.cpp and Vertical align is center than
-    // text line will cross object center 
-    const double ascent_ratio_offset = 1/3.;
 };
-
 } // namespace Slic3r::GUI
+
+namespace Slic3r::Emboss{
+/// <summary>
+/// creation line without model for backend only
+/// </summary>
+/// <param name="text_tr">Transformation of text volume inside object (aka inside of
+/// instance)</param> <param name="volumes_to_slice">Vector of volumes to be sliced</param> <param
+/// name="ff"></param> <param name="fp"></param> <param name="count_lines">Count lines of embossed
+/// text(for veritcal alignment)</param> <param name="line_height_mm_ptr">[output] line height in
+/// mm</param> <returns></returns>
+TextLines create_text_lines(
+    const Transform3d &text_tr,
+    const ModelVolumePtrs &volumes_to_slice,
+    const FontFile &ff,
+    const FontProp &fp,
+    unsigned count_lines = 1,
+    double *line_height_mm_ptr = nullptr
+);
+}
 #endif // slic3r_TextLines_hpp_
\ No newline at end of file
