@@ -8,6 +8,7 @@
 #include "BitmapCache.hpp"
 #include "GUI.hpp"
 #include "I18N.hpp"
+#include "slic3r/GUI/format.hpp"
 #include "GUI_App.hpp"
 #include "MsgDialog.hpp"
 
@@ -71,14 +72,6 @@ RammingDialog::RammingDialog(wxWindow* parent,const std::string& parameters)
 }
 
 
-#ifdef _WIN32
-#define style wxSP_ARROW_KEYS | wxBORDER_SIMPLE
-#else 
-#define style wxSP_ARROW_KEYS
-#endif
-
-
-
 RammingPanel::RammingPanel(wxWindow* parent, const std::string& parameters)
 : wxPanel(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize/*,wxPoint(50,50), wxSize(800,350),wxBORDER_RAISED*/)
 {
@@ -109,11 +102,17 @@ RammingPanel::RammingPanel(wxWindow* parent, const std::string& parameters)
 #endif
  	sizer_chart->Add(m_chart, 0, wxALL, 5);
 
-    m_widget_time						= new ::SpinInputDouble(this,"", wxEmptyString, wxDefaultPosition, wxSize(ITEM_WIDTH(), -1), style, 0., 5., 3., 0.5);
+#ifdef _WIN32
+    const long style = wxSP_ARROW_KEYS | wxBORDER_SIMPLE;
+#else 
+    const long style = wxSP_ARROW_KEYS;
+#endif
+
+    m_widget_time						= new ::SpinInputDouble(this,"", wxEmptyString, wxDefaultPosition, wxSize(ITEM_WIDTH(), -1), style, 0., 5., 3., 0.25);
     m_widget_time->SetDigits(2);
     m_widget_volume							  = new ::SpinInput(this,"",wxEmptyString,wxDefaultPosition,wxSize(ITEM_WIDTH(), -1),style,0,10000,0);
-    m_widget_ramming_line_width_multiplicator = new ::SpinInput(this,"",wxEmptyString,wxDefaultPosition,wxSize(ITEM_WIDTH(), -1),style,10,200,100);
-    m_widget_ramming_step_multiplicator		  = new ::SpinInput(this,"",wxEmptyString,wxDefaultPosition,wxSize(ITEM_WIDTH(), -1),style,10,200,100);
+    m_widget_ramming_line_width_multiplicator = new ::SpinInput(this,"",wxEmptyString,wxDefaultPosition,wxSize(ITEM_WIDTH(), -1),style,10,300,100);
+    m_widget_ramming_step_multiplicator		  = new ::SpinInput(this,"",wxEmptyString,wxDefaultPosition,wxSize(ITEM_WIDTH(), -1),style,10,300,100);
 
 #ifdef _WIN32
     update_ui(m_widget_time->GetText());
@@ -133,6 +132,15 @@ RammingPanel::RammingPanel(wxWindow* parent, const std::string& parameters)
 	gsizer_param->Add(m_widget_ramming_line_width_multiplicator);
 	gsizer_param->Add(new wxStaticText(this, wxID_ANY, wxString(_(L("Ramming line spacing")) + " (%):")), 0, wxALIGN_CENTER_VERTICAL);
 	gsizer_param->Add(m_widget_ramming_step_multiplicator);
+    gsizer_param->AddSpacer(40);
+    gsizer_param->AddSpacer(40);
+
+    std::string ctrl_str = shortkey_ctrl_prefix();
+    if (! ctrl_str.empty() && ctrl_str.back() == '+')
+        ctrl_str.pop_back();
+    // TRN: The placeholder expands to Ctrl or Cmd (on macOS).
+    gsizer_param->Add(new wxStaticText(this, wxID_ANY, format_wxstr(_L("For constant flow rate, hold %1% while dragging."), ctrl_str)), 0, wxALIGN_CENTER_VERTICAL);
+
 
 	sizer_param->Add(gsizer_param, 0, wxTOP, scale(10));
 
@@ -180,25 +188,53 @@ std::string RammingPanel::get_parameters()
 }
 
 
-// Parent dialog for purging volume adjustments - it fathers WipingPanel widget (that contains all controls) and a button to toggle simple/advanced mode:
-WipingDialog::WipingDialog(wxWindow* parent, const std::vector<float>& matrix, const std::vector<float>& extruders, const std::vector<std::string>& extruder_colours)
-: wxDialog(parent, wxID_ANY, _(L("Wipe tower - Purging volume adjustment")), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE/* | wxRESIZE_BORDER*/)
+// Parent dialog for purging volume adjustments - it fathers WipingPanel widget (that contains all controls) and a button.
+WipingDialog::WipingDialog(wxWindow* parent, const std::vector<float>& matrix, const std::vector<std::string>& extruder_colours,
+                           double printer_purging_volume, const std::vector<double>& filament_purging_multipliers, bool use_custom_matrix)
+    : wxDialog(parent, wxID_ANY, _(L("Wipe tower - Purging volume adjustment")), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE/* | wxRESIZE_BORDER*/)
 {
     SetFont(wxGetApp().normal_font());
     update_ui(this);
-    auto widget_button = new wxButton(this,wxID_ANY,"-",wxPoint(0,0),wxDefaultSize);
-    update_ui(widget_button);
-    wxGetApp().SetWindowVariantForButton(widget_button);
-    m_panel_wiping  = new WipingPanel(this,matrix,extruders, extruder_colours, widget_button);
+    m_widget_button = new wxButton(this,wxID_ANY,_L("Set values from configuration"), wxPoint(0, 0), wxDefaultSize);
+    update_ui(m_widget_button);
+    wxGetApp().SetWindowVariantForButton(m_widget_button);
 
-    auto main_sizer = new wxBoxSizer(wxVERTICAL);
+    m_radio_button1 = new wxRadioButton(this, wxID_ANY, _L("Use values from configuration"));
+    m_radio_button2 = new wxRadioButton(this, wxID_ANY, _L("Use custom project-specific settings"));
+    auto stb1        = new wxStaticBox(this, wxID_ANY, wxEmptyString);
+    auto stb2        = new wxStaticBox(this, wxID_ANY, wxEmptyString);
+
+     m_panel_wiping  = new WipingPanel(this, matrix, extruder_colours, filament_purging_multipliers, printer_purging_volume, m_widget_button);
+
+    update_ui(m_radio_button1);
+    update_ui(m_radio_button2);
+    update_ui(stb1);
+    update_ui(stb2);
+
+    auto heading_text = new wxStaticText(this, wxID_ANY, _L("The project uses single-extruder multimaterial printer with the wipe tower.\nThe volume of material used for purging can be configured here.") ,wxDefaultPosition, wxDefaultSize);
+    m_info_text1   = new wxStaticText(this, wxID_ANY, _L("Options 'multimaterial_purging' and 'filament_purge_multiplier' will be used.") ,wxDefaultPosition, wxDefaultSize);
 
 	// set min sizer width according to extruders count
-	const auto sizer_width = (int)((sqrt(matrix.size()) + 2.8)*ITEM_WIDTH());
+	const auto sizer_width = (int)((std::sqrt(matrix.size()) + 2.8)*ITEM_WIDTH());
+    auto main_sizer = new wxBoxSizer(wxVERTICAL);
 	main_sizer->SetMinSize(wxSize(sizer_width, -1));
 
-    main_sizer->Add(m_panel_wiping, 0, wxEXPAND | wxALL, 5);
-	main_sizer->Add(widget_button, 0, wxALIGN_CENTER_HORIZONTAL | wxCENTER | wxBOTTOM, 5);
+    main_sizer->Add(heading_text, 0, wxALL, 10);
+
+    main_sizer->Add(m_radio_button1, 0, wxALL, 10);
+    auto stb_sizer1 = new wxStaticBoxSizer(stb1, wxHORIZONTAL);
+    stb_sizer1->Add(m_info_text1, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 5);
+    main_sizer->Add(stb_sizer1, 0, wxALIGN_CENTER_HORIZONTAL | wxEXPAND | wxLEFT | wxRIGHT, 20);
+
+    auto t = new wxStaticText(this, wxID_ANY, _L("(all values in mm³)"), wxDefaultPosition, wxDefaultSize);
+
+    main_sizer->Add(m_radio_button2, 0, wxALL, 10);
+    auto stb_sizer2 = new wxStaticBoxSizer(stb2, wxVERTICAL);
+    stb_sizer2->Add(m_panel_wiping, 0, wxEXPAND | wxALL, 5);
+    stb_sizer2->Add(t, 0, wxALIGN_CENTER_HORIZONTAL | wxCENTER | wxBOTTOM, 5);
+    stb_sizer2->Add(m_widget_button, 0, wxALIGN_CENTER_HORIZONTAL | wxBOTTOM, 10);
+    main_sizer->Add(stb_sizer2, 0, wxALIGN_CENTER_HORIZONTAL | wxEXPAND | wxBOTTOM | wxLEFT | wxRIGHT, 20);
+
     auto buttons = CreateStdDialogButtonSizer(wxOK | wxCANCEL);
     wxGetApp().SetWindowVariantForButton(buttons->GetAffirmativeButton());
     wxGetApp().SetWindowVariantForButton(buttons->GetCancelButton());
@@ -213,32 +249,49 @@ WipingDialog::WipingDialog(wxWindow* parent, const std::vector<float>& matrix, c
     
     this->Bind(wxEVT_BUTTON,[this](wxCommandEvent&) {                 // if OK button is clicked..
         m_output_matrix    = m_panel_wiping->read_matrix_values();    // ..query wiping panel and save returned values
-        m_output_extruders = m_panel_wiping->read_extruders_values(); // so they can be recovered later by calling get_...()
         EndModal(wxID_OK);
         },wxID_OK);
 
+    this->Bind(wxEVT_RADIOBUTTON, [this](wxCommandEvent&) {
+        enable_or_disable_panel();
+    });
+
+    m_radio_button1->SetValue(! use_custom_matrix);
+    m_radio_button2->SetValue(use_custom_matrix);
+    enable_or_disable_panel();
+
     this->Show();
+
 }
 
-// This function allows to "play" with sizers parameters (like align or border)
-void WipingPanel::format_sizer(wxSizer* sizer, wxPanel* page, wxGridSizer* grid_sizer, const wxString& info, const wxString& table_title, int table_lshift/*=0*/)
+// This function allows to "play" with sizrs parameters (like align or border)
+void WipingPanel::format_sizer(wxSizer* sizer, wxPanel* page, wxGridSizer* grid_sizer, const wxString& table_title, int table_lshift/*=0*/)
 {
-    wxSize text_size = GetTextExtent(info);
-    auto info_str = new wxStaticText(page, wxID_ANY, info ,wxDefaultPosition, wxDefaultSize, wxALIGN_CENTER);
-    info_str->Wrap(int(0.6*text_size.x));
-	sizer->Add( info_str, 0, wxEXPAND);
 	auto table_sizer = new wxBoxSizer(wxVERTICAL);
 	sizer->Add(table_sizer, 0, wxALIGN_CENTER | wxCENTER, table_lshift);
-	table_sizer->Add(new wxStaticText(page, wxID_ANY, table_title), 0, wxALIGN_CENTER | wxTOP, 50);
-	table_sizer->Add(grid_sizer, 0, wxALIGN_CENTER | wxTOP, 10);
+	table_sizer->Add(new wxStaticText(page, wxID_ANY, table_title), 0, wxALIGN_CENTER | wxTOP, 10);
+	table_sizer->Add(grid_sizer, 0, wxALIGN_CENTER | wxTOP | wxLEFT, 15);
 }
 
-// This panel contains all control widgets for both simple and advanced mode (these reside in separate sizers)
-WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, const std::vector<float>& extruders, const std::vector<std::string>& extruder_colours, wxButton* widget_button)
+
+WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, const std::vector<std::string>& extruder_colours,
+                         const std::vector<double>& filament_purging_multipliers, double printer_purging_volume, wxButton* widget_button)
 : wxPanel(parent,wxID_ANY, wxDefaultPosition, wxDefaultSize/*,wxBORDER_RAISED*/)
 {
+    m_filament_purging_multipliers = filament_purging_multipliers;
+    m_printer_purging_volume = printer_purging_volume;
     m_widget_button = widget_button;    // pointer to the button in parent dialog
-    m_widget_button->Bind(wxEVT_BUTTON,[this](wxCommandEvent&){ toggle_advanced(true); });
+    m_widget_button->Bind(wxEVT_BUTTON,[this](wxCommandEvent&){
+        // Set the matrix to defaults.
+        for (size_t i = 0; i < m_number_of_extruders; ++i) {
+            for (size_t j = 0; j < m_number_of_extruders; ++j) {
+                if (i != j) {
+                    double def_val = m_printer_purging_volume * m_filament_purging_multipliers[j] / 100.;
+                    edit_boxes[j][i]->SetValue(wxString("") << int(def_val));
+                }
+            }
+        }
+    });
 
     m_number_of_extruders = (int)(sqrt(matrix.size())+0.001);
 
@@ -248,18 +301,12 @@ WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, con
         m_colours.push_back(wxColor(rgb.r_uchar(), rgb.g_uchar(), rgb.b_uchar()));
     }
 
-	// Create two switched panels with their own sizers
-    m_sizer_simple          = new wxBoxSizer(wxVERTICAL);
     m_sizer_advanced        = new wxBoxSizer(wxVERTICAL);
-	m_page_simple			= new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL);
 	m_page_advanced			= new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL);
-	m_page_simple->SetSizer(m_sizer_simple);
 	m_page_advanced->SetSizer(m_sizer_advanced);
 
-    update_ui(m_page_simple);
     update_ui(m_page_advanced);
 
-    auto gridsizer_simple   = new wxGridSizer(3, 5, 10);
     m_gridsizer_advanced = new wxGridSizer(m_number_of_extruders+1, 5, 1);
 
 	// First create controls for advanced mode and assign them to m_page_advanced:
@@ -312,57 +359,15 @@ WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, con
     }
 
 	// collect and format sizer
-	format_sizer(m_sizer_advanced, m_page_advanced, m_gridsizer_advanced,
-		_(L("Here you can adjust required purging volume (mm³) for any given pair of tools.")),
-		_(L("Extruder changed to")));
+	format_sizer(m_sizer_advanced, m_page_advanced, m_gridsizer_advanced, _(L("Extruder changed to")));
 
-	// Hide preview page before new page creating 
-	// It allows to do that from a beginning of the main panel
-	m_page_advanced->Hide(); 
-
-	// Now the same for simple mode:
-	gridsizer_simple->Add(new wxStaticText(m_page_simple, wxID_ANY, wxString("")), 0, wxALIGN_CENTER | wxALIGN_CENTER_VERTICAL);
-	gridsizer_simple->Add(new wxStaticText(m_page_simple, wxID_ANY, wxString(_(L("unloaded")))), 0, wxALIGN_CENTER | wxALIGN_CENTER_VERTICAL);
-    gridsizer_simple->Add(new wxStaticText(m_page_simple,wxID_ANY,wxString(_(L("loaded")))), 0, wxALIGN_CENTER | wxALIGN_CENTER_VERTICAL);
-
-    auto add_spin_ctrl = [this](std::vector<::SpinInput*>& vec, float initial)
-    {
-        ::SpinInput* spin_ctrl = new ::SpinInput(m_page_simple, "", wxEmptyString, wxDefaultPosition, wxSize(ITEM_WIDTH(), -1), style | wxALIGN_RIGHT, 0, 300, (int)initial);
-        update_ui(spin_ctrl);
-        vec.push_back(spin_ctrl);
-    };
-
-	for (unsigned int i=0;i<m_number_of_extruders;++i) {
-        add_spin_ctrl(m_old, extruders[2 * i]);
-        add_spin_ctrl(m_new, extruders[2 * i+1]);
-
-        auto hsizer = new wxBoxSizer(wxHORIZONTAL);
-        wxWindow* w = new wxWindow(m_page_simple, wxID_ANY, wxDefaultPosition, icon_size, wxBORDER_SIMPLE);
-        w->SetCanFocus(false);
-        w->SetBackgroundColour(m_colours[i]);
-        hsizer->Add(w, wxALIGN_CENTER_VERTICAL);
-        hsizer->AddSpacer(10);
-        hsizer->Add(new wxStaticText(m_page_simple, wxID_ANY, wxString(_(L("Tool #"))) << i + 1 << ": "), 0, wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL);
-
-        gridsizer_simple->Add(hsizer, 1, wxEXPAND);
-        gridsizer_simple->Add(m_old.back(),0);
-        gridsizer_simple->Add(m_new.back(),0);
-	}
-
-	// collect and format sizer
-	format_sizer(m_sizer_simple, m_page_simple, gridsizer_simple,
-		_(L("Total purging volume is calculated by summing two values below, depending on which tools are loaded/unloaded.")),
-		_(L("Volume to purge (mm³) when the filament is being")), 50);
 
 	m_sizer = new wxBoxSizer(wxVERTICAL);
-	m_sizer->Add(m_page_simple, 0, wxEXPAND | wxALL, 25);
-	m_sizer->Add(m_page_advanced, 0, wxEXPAND | wxALL, 25);
+	m_sizer->Add(m_page_advanced, 0, wxEXPAND | wxALL, 5);
 
 	m_sizer->SetSizeHints(this);
 	SetSizer(m_sizer);
 
-    toggle_advanced(); // to show/hide what is appropriate
-    
     m_page_advanced->Bind(wxEVT_PAINT,[this](wxPaintEvent&) {
                                               wxPaintDC dc(m_page_advanced);
                                               int y_pos = 0.5 * (edit_boxes[0][0]->GetPosition().y + edit_boxes[0][edit_boxes.size()-1]->GetPosition().y + edit_boxes[0][edit_boxes.size()-1]->GetSize().y);
@@ -370,8 +375,24 @@ WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, con
                                               int text_width = 0;
                                               int text_height = 0;
                                               dc.GetTextExtent(label,&text_width,&text_height);
+
                                               int xpos = m_gridsizer_advanced->GetPosition().x;
-                                              dc.DrawRotatedText(label,xpos-text_height,y_pos + text_width/2.f,90);
+                                              if (!m_page_advanced->IsEnabled()) {
+                                                  dc.SetTextForeground(wxSystemSettings::GetColour(
+#if defined (__linux__) && defined (__WXGTK2__)
+                                                      wxSYS_COLOUR_BTNTEXT
+#else 
+                                                      wxSYS_COLOUR_GRAYTEXT
+#endif 
+                                                      ));
+                                                  dc.DrawRotatedText(label, xpos - text_height, y_pos + text_width / 2.f, 90);
+#ifdef _WIN32
+                                                  dc.SetTextForeground(wxSystemSettings::GetColour(wxSYS_COLOUR_3DLIGHT));
+                                                  dc.DrawRotatedText(label, xpos - text_height-1, y_pos + text_width / 2.f+1, 90);
+#endif
+                                              }
+                                              else
+                                                  dc.DrawRotatedText(label, xpos - text_height, y_pos + text_width / 2.f, 90);
     });
 }
 
@@ -380,8 +401,6 @@ WipingPanel::WipingPanel(wxWindow* parent, const std::vector<float>& matrix, con
 
 // Reads values from the (advanced) wiping matrix:
 std::vector<float> WipingPanel::read_matrix_values() {
-    if (!m_advanced)
-        fill_in_matrix();
     std::vector<float> output;
     for (unsigned int i=0;i<m_number_of_extruders;++i) {
         for (unsigned int j=0;j<m_number_of_extruders;++j) {
@@ -393,60 +412,12 @@ std::vector<float> WipingPanel::read_matrix_values() {
     return output;
 }
 
-// Reads values from simple mode to save them for next time:
-std::vector<float> WipingPanel::read_extruders_values() {
-    std::vector<float> output;
-    for (unsigned int i=0;i<m_number_of_extruders;++i) {
-        output.push_back(m_old[i]->GetValue());
-        output.push_back(m_new[i]->GetValue());
-    }
-    return output;
-}
 
-// This updates the "advanced" matrix based on values from "simple" mode
-void WipingPanel::fill_in_matrix() {
-    for (unsigned i=0;i<m_number_of_extruders;++i) {
-        for (unsigned j=0;j<m_number_of_extruders;++j) {
-            if (i==j) continue;
-                edit_boxes[j][i]->SetValue(wxString("")<< (m_old[i]->GetValue() + m_new[j]->GetValue()));
-        }
-    }
-}
-
-
-
-// Function to check if simple and advanced settings are matching
-bool WipingPanel::advanced_matches_simple() {
-    for (unsigned i=0;i<m_number_of_extruders;++i) {
-        for (unsigned j=0;j<m_number_of_extruders;++j) {
-            if (i==j) continue;
-            if (edit_boxes[j][i]->GetValue() != (wxString("")<< (m_old[i]->GetValue() + m_new[j]->GetValue())))
-                return false;
-        }
-    }
-    return true;
-}
-
-
-// Switches the dialog from simple to advanced mode and vice versa
-void WipingPanel::toggle_advanced(bool user_action) {
-    if (m_advanced && !advanced_matches_simple() && user_action) {
-        if (MessageDialog(this, _L("Switching to simple settings will discard changes done in the advanced mode!\n\nDo you want to proceed?"),
-                            _L("Warning"),wxYES_NO|wxICON_EXCLAMATION).ShowModal() != wxID_YES)
-            return;
-    }
-    if (user_action)
-        m_advanced = !m_advanced;                // user demands a change -> toggle
-    else
-        m_advanced = !advanced_matches_simple(); // if called from constructor, show what is appropriate
-
-    (m_advanced ? m_page_advanced : m_page_simple)->Show();
-	(!m_advanced ? m_page_advanced : m_page_simple)->Hide();
-
-    m_widget_button->SetLabel(m_advanced ? _(L("Show simplified settings")) : _(L("Show advanced settings")));
-    if (m_advanced)
-        if (user_action) fill_in_matrix();  // otherwise keep values loaded from config
-
-   m_sizer->Layout();
-   Refresh();
-}
+void WipingDialog::enable_or_disable_panel()
+{
+    bool enable = m_radio_button2->GetValue();
+    m_info_text1->Enable(! enable);
+    m_widget_button->Enable(enable);
+    m_panel_wiping->Enable(enable);
+    m_panel_wiping->Refresh();
+}
\ No newline at end of file
