@@ -1,10 +1,13 @@
 #import "MacDarkMode.hpp"
 
+#include "wx/osx/core/cfstring.h"
+
 #import <algorithm>
 
 #import <Cocoa/Cocoa.h>
 #import <Foundation/Foundation.h>
 #import <AppKit/NSScreen.h>
+#import <WebKit/WebKit.h>
 
 @interface MacDarkMode : NSObject {}
 @end
@@ -33,6 +36,16 @@ double mac_max_scaling_factor()
     return scaling;
 }
 
+void WKWebView_evaluateJavaScript(void * web, wxString const & script, void (*callback)(wxString const &))
+{
+    [(WKWebView*)web evaluateJavaScript:wxCFStringRef(script).AsNSString() completionHandler: ^(id result, NSError *error) {
+        if (callback && error != nil) {
+            wxString err = wxCFStringRef(error.localizedFailureReason).AsString();
+            callback(err);
+        }
+    }];
+}
+
 }
 }
 
