@@ -1,6 +1,6 @@
 #include <iostream>
 #include <fstream>
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 #include "libslic3r/SLA/Hollowing.hpp"
 
